https://svn.lrde.epita.fr/svn/oln/branches/cleanup-2008/milena
Index: ChangeLog
from Thierry Geraud <thierry.geraud(a)lrde.epita.fr>
Rename pset_if as p_if and remove Q at end of priority_Q.
* mln/core/site_set/pset_if.hh,
* mln/core/pset_if_piter.hh: Rename as...
* mln/core/site_set/p_if.hh,
* mln/core/site_set/p_if_piter.hh: ...these.
* mln/core/site_set/p_priority_queue.hh: Rename as...
* mln/core/site_set/p_priority.hh: ...this.
* tests/core/p_priority_queue.cc,
* tests/core/p_priority_queue_fast_with_array.cc,
* tests/core/pset_if.cc,
* tests/core/p_priority_queue_fast.cc,
* tests/convert/to_image.cc,
* doc/tutorial/examples/image_if.cc,
* doc/tutorial/examples/p_queue.cc,
* mln/core/site_set/p_image.hh,
* mln/core/image/image_if.hh,
* mln/core/internal/image_if_base.hh,
* mln/draw/label.hh,
* mln/geom/seeds2tiling_roundness.hh,
* mln/morpho/meyer_wst.hh,
* sandbox/pellegrin/set/test/p_priority_queue_fast.cc,
* sandbox/pellegrin/set/test/p_priority_queue.cc,
* sandbox/pellegrin/set/test/pset_if.cc,
* sandbox/pellegrin/set/test/p_priority_queue_fast_with_array.cc,
* sandbox/pellegrin/set/trait/point_set.hh,
* sandbox/pellegrin/set/core/p_priority_queue_fast.hh,
* sandbox/pellegrin/set/core/pset_if.hh,
* sandbox/pellegrin/set/core/concept/point_set.hh,
* sandbox/pellegrin/set/core/p_priority_queue.hh,
* sandbox/pellegrin/set/core/p_priority_queue_fast_with_array.hh,
* sandbox/garrigues/level_set.hh,
* sandbox/garrigues/fllt/fllt.hh: Update.
doc/tutorial/examples/image_if.cc | 2
doc/tutorial/examples/p_queue.cc | 2
mln/core/image/image_if.hh | 10 -
mln/core/internal/image_if_base.hh | 10 -
mln/core/site_set/p_if.hh | 52 +++++-----
mln/core/site_set/p_if_piter.hh | 40 +++----
mln/core/site_set/p_image.hh | 4
mln/draw/label.hh | 2
mln/geom/seeds2tiling_roundness.hh | 4
mln/morpho/meyer_wst.hh | 2
sandbox/garrigues/fllt/fllt.hh | 4
sandbox/garrigues/level_set.hh | 4
sandbox/pellegrin/set/core/concept/point_set.hh | 2
sandbox/pellegrin/set/core/p_priority_queue.hh | 50 ++++-----
sandbox/pellegrin/set/core/p_priority_queue_fast.hh | 50 ++++-----
sandbox/pellegrin/set/core/p_priority_queue_fast_with_array.hh | 50 ++++-----
sandbox/pellegrin/set/core/pset_if.hh | 52 +++++-----
sandbox/pellegrin/set/test/p_priority_queue.cc | 8 -
sandbox/pellegrin/set/test/p_priority_queue_fast.cc | 8 -
sandbox/pellegrin/set/test/p_priority_queue_fast_with_array.cc | 8 -
sandbox/pellegrin/set/test/pset_if.cc | 6 -
sandbox/pellegrin/set/trait/point_set.hh | 8 -
tests/convert/to_image.cc | 2
tests/core/p_priority_queue.cc | 8 -
tests/core/p_priority_queue_fast.cc | 8 -
tests/core/p_priority_queue_fast_with_array.cc | 8 -
tests/core/pset_if.cc | 6 -
27 files changed, 205 insertions(+), 205 deletions(-)
Index: tests/core/pset_if.cc
--- tests/core/pset_if.cc (revision 2175)
+++ tests/core/pset_if.cc (working copy)
@@ -25,14 +25,14 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-/*! \file tests/core/pset_if.cc
+/*! \file tests/core/p_if.cc
*
- * \brief Tests on mln::pset_if.
+ * \brief Tests on mln::p_if.
*/
#include <mln/core/image/image2d.hh>
#include <mln/core/site_set/p_set.hh>
-#include <mln/core/site_set/pset_if.hh>
+#include <mln/core/site_set/p_if.hh>
#include <mln/fun/p2b/chess.hh>
#include <mln/convert/to_image.hh>
#include <mln/convert/to_p_set.hh>
Index: tests/convert/to_image.cc
--- tests/convert/to_image.cc (revision 2175)
+++ tests/convert/to_image.cc (working copy)
@@ -32,7 +32,7 @@
#include <mln/core/image/image2d.hh>
#include <mln/core/alias/window2d.hh>
-#include <mln/core/site_set/pset_if.hh>
+#include <mln/core/site_set/p_if.hh>
#include <mln/fun/p2b/chess.hh>
#include <mln/level/compare.hh>
Index: doc/tutorial/examples/image_if.cc
--- doc/tutorial/examples/image_if.cc (revision 2175)
+++ doc/tutorial/examples/image_if.cc (working copy)
@@ -71,7 +71,7 @@
trait::image::print(ima_);
std::cout << std::endl;
- typedef pset_if<box2d, fun::p2b::chess_t> S;
+ typedef p_if<box2d, fun::p2b::chess_t> S;
ch_target(mln_fwd_piter_(S)(), ima_.domain());
// mln_VAR(ima_e, extend(ima_, pw::value(ima)));
Index: doc/tutorial/examples/p_queue.cc
--- doc/tutorial/examples/p_queue.cc (revision 2175)
+++ doc/tutorial/examples/p_queue.cc (working copy)
@@ -4,7 +4,7 @@
# include <mln/debug/println.hh>
# include <mln/level/fill.hh>
-# include <mln/core/site_set/p_priority_queue.hh>
+# include <mln/core/site_set/p_priority.hh>
Index: mln/core/site_set/p_image.hh
--- mln/core/site_set/p_image.hh (revision 2175)
+++ mln/core/site_set/p_image.hh (working copy)
@@ -37,7 +37,7 @@
* \todo Add an init method (deferred initialization).
*/
-# include <mln/core/site_set/pset_if.hh>
+# include <mln/core/site_set/p_if.hh>
# include <mln/fun/ops.hh>
# include <mln/pw/value.hh>
# include <mln/pw/cst.hh>
@@ -76,7 +76,7 @@
public:
/// Equivalent site_set type.
- typedef pset_if<S_, F_> S;
+ typedef p_if<S_, F_> S;
/// Conversion towards the equivalent site set.
operator S() const;
Index: mln/core/site_set/p_if.hh
--- mln/core/site_set/p_if.hh (revision 2175)
+++ mln/core/site_set/p_if.hh (working copy)
@@ -25,10 +25,10 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-#ifndef MLN_CORE_SITE_SET_PSET_IF_HH
-# define MLN_CORE_SITE_SET_PSET_IF_HH
+#ifndef MLN_CORE_SITE_SET_P_IF_HH
+# define MLN_CORE_SITE_SET_P_IF_HH
-/*! \file mln/core/site_set/pset_if.hh
+/*! \file mln/core/site_set/p_if.hh
*
* \brief Definition of the restriction of a point set w.r.t. a predicate.
*
@@ -43,15 +43,15 @@
{
// Fwd decls.
- template <typename S, typename F> struct pset_if;
- template <typename Pi, typename S, typename F> struct pset_if_piter_;
+ template <typename S, typename F> struct p_if;
+ template <typename Pi, typename S, typename F> struct p_if_piter_;
namespace trait
{
template <typename S, typename F>
- struct site_set_< pset_if<S,F> >
+ struct site_set_< p_if<S,F> >
{
typedef trait::site_set::nsites::unknown nsites;
typedef trait::site_set::bbox::unknown bbox;
@@ -69,7 +69,7 @@
* \return A subset of points.
*/
template <typename S, typename F>
- pset_if<S, F>
+ p_if<S, F>
operator | (const Site_Set<S>& pset, const Function_p2b<F>& f);
@@ -80,9 +80,9 @@
* from point to Boolean.
*/
template <typename S, typename F>
- class pset_if : public internal::site_set_base_< mln_psite(S), pset_if<S,F>
>
+ class p_if : public internal::site_set_base_< mln_psite(S), p_if<S,F> >
{
- typedef pset_if<S,F> self_;
+ typedef p_if<S,F> self_;
typedef internal::site_set_base_<mln_psite(S), self_> super_;
public:
@@ -94,20 +94,20 @@
typedef mln_psite(S) psite;
/// Forward Site_Iterator associated type.
- typedef pset_if_piter_<mln_fwd_piter(S), S, F> fwd_piter;
+ typedef p_if_piter_<mln_fwd_piter(S), S, F> fwd_piter;
/// Backward Site_Iterator associated type.
- typedef pset_if_piter_<mln_bkd_piter(S), S, F> bkd_piter;
+ typedef p_if_piter_<mln_bkd_piter(S), S, F> bkd_piter;
/// Site_Iterator associated type.
typedef fwd_piter piter;
/// Constructor with a point set \p pset and a predicate \p f.
- pset_if(const S& pset, const F& f);
+ p_if(const S& pset, const F& f);
/// Constructor without argument.
- pset_if();
+ p_if();
/// Test if this site set is valid.
@@ -143,20 +143,20 @@
template <typename S, typename F>
inline
- pset_if<S, F>
+ p_if<S, F>
operator | (const Site_Set<S>& pset, const Function_p2b<F>& f)
{
- pset_if<S, F> tmp(exact(pset), exact(f));
+ p_if<S, F> tmp(exact(pset), exact(f));
return tmp;
}
- // pset_if<S,F>
+ // p_if<S,F>
template <typename S, typename F>
inline
bool
- pset_if<S,F>::has(const psite& p) const
+ p_if<S,F>::has(const psite& p) const
{
return pset_.has(p) && f_(p);
}
@@ -164,7 +164,7 @@
template <typename S, typename F>
inline
bool
- pset_if<S,F>::is_valid() const
+ p_if<S,F>::is_valid() const
{
return pset_.is_valid();
}
@@ -172,7 +172,7 @@
template <typename S, typename F>
inline
const S&
- pset_if<S,F>::overset() const
+ p_if<S,F>::overset() const
{
return pset_;
}
@@ -180,14 +180,14 @@
template <typename S, typename F>
inline
bool
- pset_if<S,F>::pred(const psite& p) const
+ p_if<S,F>::pred(const psite& p) const
{
return f_(p);
}
template <typename S, typename F>
inline
- pset_if<S,F>::pset_if(const S& pset, const F& f)
+ p_if<S,F>::p_if(const S& pset, const F& f)
: pset_(pset),
f_(f)
{
@@ -195,14 +195,14 @@
template <typename S, typename F>
inline
- pset_if<S,F>::pset_if()
+ p_if<S,F>::p_if()
{
}
template <typename S, typename F>
inline
const F&
- pset_if<S,F>::predicate() const
+ p_if<S,F>::predicate() const
{
return f_;
}
@@ -210,7 +210,7 @@
template <typename S, typename F>
inline
std::size_t
- pset_if<S,F>::memory_size() const
+ p_if<S,F>::memory_size() const
{
return pset_.memory_size() + sizeof(f_);
}
@@ -221,8 +221,8 @@
-# include <mln/core/pset_if_piter.hh>
+# include <mln/core/p_if_piter.hh>
-#endif // ! MLN_CORE_SITE_SET_PSET_IF_HH
+#endif // ! MLN_CORE_SITE_SET_P_IF_HH
Index: mln/core/image/image_if.hh
--- mln/core/image/image_if.hh (revision 2175)
+++ mln/core/image/image_if.hh (working copy)
@@ -37,7 +37,7 @@
*/
# include <mln/core/internal/image_domain_morpher.hh>
-# include <mln/core/site_set/pset_if.hh>
+# include <mln/core/site_set/p_if.hh>
# include <mln/pw/all.hh>
@@ -58,7 +58,7 @@
data(I& ima, const F& f);
I ima_;
- pset_if<mln_pset(I), F> pset_;
+ p_if<mln_pset(I), F> pset_;
};
} // end of namespace mln::internal
@@ -90,7 +90,7 @@
*/
template <typename I, typename F>
struct image_if : public internal::image_domain_morpher< I,
- pset_if<mln_pset(I), F>,
+ p_if<mln_pset(I), F>,
image_if<I, F> >
{
/// Skeleton.
@@ -105,7 +105,7 @@
void init_(I& ima, const F& f);
/// Give the definition domain.
- const pset_if<mln_pset(I), F>& domain() const;
+ const p_if<mln_pset(I), F>& domain() const;
/// Const promotion via conversion.
operator image_if<const I, F>() const;
@@ -193,7 +193,7 @@
template <typename I, typename F>
inline
- const pset_if<mln_pset(I), F>&
+ const p_if<mln_pset(I), F>&
image_if<I,F>::domain() const
{
mln_precondition(this->has_data());
Index: mln/core/internal/image_if_base.hh
--- mln/core/internal/image_if_base.hh (revision 2175)
+++ mln/core/internal/image_if_base.hh (working copy)
@@ -34,7 +34,7 @@
*/
# include <mln/core/internal/image_domain_morpher.hh>
-# include <mln/core/site_set/pset_if.hh>
+# include <mln/core/site_set/p_if.hh>
# include <mln/pw/all.hh>
# include <mln/value/interval.hh>
@@ -57,7 +57,7 @@
data_(I& ima, const F& f);
I ima_;
- pset_if<mln_pset(I), F> pset_;
+ p_if<mln_pset(I), F> pset_;
};
} // end of namespace mln::internal
@@ -99,11 +99,11 @@
*
*/
template <typename I, typename F, typename E>
- struct image_if_base_ : public internal::image_domain_morpher< I,
pset_if<mln_pset(I),F>, E >
+ struct image_if_base_ : public internal::image_domain_morpher< I,
p_if<mln_pset(I),F>, E >
{
/// Give the definition domain.
- const pset_if<mln_pset(I), F>& domain() const;
+ const p_if<mln_pset(I), F>& domain() const;
void init_(I& ima, const F& f);
@@ -186,7 +186,7 @@
template <typename I, typename F, typename E>
inline
- const pset_if<mln_pset(I), F>&
+ const p_if<mln_pset(I), F>&
image_if_base_<I,F,E>::domain() const
{
return this->data_->pset_;
Index: mln/draw/label.hh
--- mln/draw/label.hh (revision 2175)
+++ mln/draw/label.hh (working copy)
@@ -77,7 +77,7 @@
{
typedef mln_value(I) V;
typedef mln_ch_value(I, value::rgb8) O;
- typedef const mln::pset_if<mln_pset(I),
mln::fun::eq_p2b_expr_<mln::pw::value_<I>, mln::pw::cst_<V> > > F;
+ typedef const mln::p_if<mln_pset(I),
mln::fun::eq_p2b_expr_<mln::pw::value_<I>, mln::pw::cst_<V> > > F;
I in = exact(input);
mln_precondition(in.has_data());
Index: mln/geom/seeds2tiling_roundness.hh
--- mln/geom/seeds2tiling_roundness.hh (revision 2175)
+++ mln/geom/seeds2tiling_roundness.hh (working copy)
@@ -37,7 +37,7 @@
# include <mln/core/concept/neighborhood.hh>
-# include <mln/core/p_priority_queue_fast.hh>
+# include <mln/core/p_priority_fast.hh>
# include <mln/core/routine/clone.hh>
# include <mln/accu/mean.hh>
# include <mln/estim/min_max.hh>
@@ -86,7 +86,7 @@
I& ima = exact(ima_);
image2d<unsigned> dist = geom::chamfer(ima, w_win, max);
I out = clone(ima_);
- p_priority_queue_fast<mln_psite(I), unsigned> q;
+ p_priority_fast<mln_psite(I), unsigned> q;
// Init.
{
Index: mln/morpho/meyer_wst.hh
--- mln/morpho/meyer_wst.hh (revision 2175)
+++ mln/morpho/meyer_wst.hh (working copy)
@@ -120,7 +120,7 @@
// Ordered queue.
/* FIXME: Milena probably already provides an ordered queue
- facility via the mln::p_priority_queue class. Try to use it
+ facility via the mln::p_priority class. Try to use it
instead, and get rid of mln/util/greater_psite.hh. */
typedef
std::priority_queue< psite, std::vector<psite>, util::greater_psite<I>
>
Index: sandbox/pellegrin/set/test/pset_if.cc
--- sandbox/pellegrin/set/test/pset_if.cc (revision 2175)
+++ sandbox/pellegrin/set/test/pset_if.cc (working copy)
@@ -25,14 +25,14 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-/*! \file tests/core_pset_if.cc
+/*! \file tests/core_p_if.cc
*
- * \brief Tests on mln::pset_if.
+ * \brief Tests on mln::p_if.
*/
#include <mln/core/image/image2d.hh>
#include <mln/core/site_set/p_set.hh>
-#include <mln/core/site_set/pset_if.hh>
+#include <mln/core/site_set/p_if.hh>
#include <mln/fun/p2b/chess.hh>
#include <mln/convert/to_image.hh>
#include <mln/convert/to_p_set.hh>
Index: sandbox/pellegrin/set/trait/point_set.hh
--- sandbox/pellegrin/set/trait/point_set.hh (revision 2175)
+++ sandbox/pellegrin/set/trait/point_set.hh (working copy)
@@ -47,15 +47,15 @@
template <typename P> struct p_bgraph;
template <typename P> struct p_graph;
template <typename P> struct p_line_graph;
- template <typename P, typename T> struct p_priority_queue;
- template <typename P, typename T> struct p_priority_queue_fast;
- template <typename P, typename T, unsigned S> struct
p_priority_queue_fast_with_array;
+ template <typename P, typename T> struct p_priority;
+ template <typename P, typename T> struct p_priority_fast;
+ template <typename P, typename T, unsigned S> struct p_priority_fast_with_array;
template <typename P> struct p_queue;
template <typename P> struct p_queue_fast;
template <typename P> struct p_run;
template <typename P> struct p_runs_;
template <typename P> struct p_set;
- template <typename S, typename F> struct pset_if;
+ template <typename S, typename F> struct p_if;
namespace trait
{
Index: sandbox/pellegrin/set/core/p_priority_queue_fast.hh
--- sandbox/pellegrin/set/core/p_priority_queue_fast.hh (revision 2175)
+++ sandbox/pellegrin/set/core/p_priority_queue_fast.hh (working copy)
@@ -28,7 +28,7 @@
#ifndef MLN_CORE_SITE_SET_P_PRIORITY_QUEUE_FAST_HH
# define MLN_CORE_SITE_SET_P_PRIORITY_QUEUE_FAST_HH
-/*! \file mln/core/p_priority_queue_fast.hh
+/*! \file mln/core/p_priority_fast.hh
*
* \brief Definition of a point set class based on p_queue_fast with
* priority features.
@@ -51,7 +51,7 @@
{
// Fwd decls.
- template <typename P, typename T> struct p_priority_queue_fast;
+ template <typename P, typename T> struct p_priority_fast;
template <typename P> struct p_array_fwd_piter_;
template <typename P> struct p_array_bkd_piter_;
@@ -59,8 +59,8 @@
{
template <typename P, typename T>
- struct point_set_< p_priority_queue_fast<P, T> >
- : public default_point_set_< p_priority_queue_fast<P, T> >
+ struct point_set_< p_priority_fast<P, T> >
+ : public default_point_set_< p_priority_fast<P, T> >
{
typedef trait::point_set::arity::unique arity;
typedef trait::point_set::has_speed::fast has_speed;
@@ -78,7 +78,7 @@
* a call to npoints() when this container is multiple.
*/
template <typename P, typename T>
- class p_priority_queue_fast : public internal::point_set_base_< P,
p_priority_queue_fast<P, T> >
+ class p_priority_fast : public internal::point_set_base_< P, p_priority_fast<P,
T> >
{
public:
@@ -89,7 +89,7 @@
typedef p_array_bkd_piter_<P> bkd_piter;
/// Constructor.
- p_priority_queue_fast();
+ p_priority_fast();
/// Test is \p p belongs to this point set.
bool has(const P& p) const;
@@ -104,10 +104,10 @@
const box_<P>& bbox() const;
/// Push force a point \p p in the queue.
- p_priority_queue_fast<P, T>& push_force(const P& p, T prio = 0);
+ p_priority_fast<P, T>& push_force(const P& p, T prio = 0);
/// Push a point \p p in the queue.
- p_priority_queue_fast<P, T>& push(const P& p, T prio = 0);
+ p_priority_fast<P, T>& push(const P& p, T prio = 0);
/// Pop (remove) the front point \p p from the queue; \p p is the
/// least recently inserted point.
@@ -151,7 +151,7 @@
template <typename P, typename T>
inline
- p_priority_queue_fast<P, T>::p_priority_queue_fast()
+ p_priority_fast<P, T>::p_priority_fast()
{
vect_needs_update_ = false;
bb_needs_update_ = false;
@@ -160,7 +160,7 @@
template <typename P, typename T>
inline
void
- p_priority_queue_fast<P, T>::vect_update_() const
+ p_priority_fast<P, T>::vect_update_() const
{
vect_.clear();
vect_.reserve(npoints());
@@ -176,7 +176,7 @@
template <typename P, typename T>
inline
void
- p_priority_queue_fast<P, T>::bb_update_() const
+ p_priority_fast<P, T>::bb_update_() const
{
bb_.init();
@@ -192,7 +192,7 @@
template <typename P, typename T>
inline
bool
- p_priority_queue_fast<P, T>::has(const P& p) const
+ p_priority_fast<P, T>::has(const P& p) const
{
typename std::map<T, p_queue_fast<P> >::const_iterator it = q_.begin ();
@@ -205,7 +205,7 @@
template <typename P, typename T>
inline
bool
- p_priority_queue_fast<P, T>::is_empty() const
+ p_priority_fast<P, T>::is_empty() const
{
typename std::map<T, p_queue_fast<P> >::const_iterator it = q_.begin ();
@@ -218,7 +218,7 @@
template <typename P, typename T>
inline
size_t
- p_priority_queue_fast<P, T>::npoints() const
+ p_priority_fast<P, T>::npoints() const
{
unsigned res = 0;
@@ -233,7 +233,7 @@
template <typename P, typename T>
inline
const box_<P>&
- p_priority_queue_fast<P, T>::bbox() const
+ p_priority_fast<P, T>::bbox() const
{
mln_precondition(npoints() != 0);
if (bb_needs_update_)
@@ -243,8 +243,8 @@
template <typename P, typename T>
inline
- p_priority_queue_fast<P, T>&
- p_priority_queue_fast<P, T>::push_force(const P& p, T prio)
+ p_priority_fast<P, T>&
+ p_priority_fast<P, T>::push_force(const P& p, T prio)
{
q_[prio].push_force (p);
if (! vect_needs_update_)
@@ -257,8 +257,8 @@
template <typename P, typename T>
inline
- p_priority_queue_fast<P, T>&
- p_priority_queue_fast<P, T>::push(const P& p, T prio)
+ p_priority_fast<P, T>&
+ p_priority_fast<P, T>::push(const P& p, T prio)
{
if (! has(p))
return this->push_force(p, prio);
@@ -269,7 +269,7 @@
template <typename P, typename T>
inline
void
- p_priority_queue_fast<P, T>::pop()
+ p_priority_fast<P, T>::pop()
{
typename std::map<T, p_queue_fast<P> >::reverse_iterator it = q_.rbegin
();
@@ -287,7 +287,7 @@
template <typename P, typename T>
inline
const P&
- p_priority_queue_fast<P, T>::front() const
+ p_priority_fast<P, T>::front() const
{
mln_precondition(! q_.empty());
@@ -302,7 +302,7 @@
template <typename P, typename T>
inline
const P&
- p_priority_queue_fast<P, T>::pop_front()
+ p_priority_fast<P, T>::pop_front()
{
const P& res = this->front();
@@ -313,7 +313,7 @@
template <typename P, typename T>
inline
void
- p_priority_queue_fast<P, T>::clear()
+ p_priority_fast<P, T>::clear()
{
typename std::map<T, p_queue_fast<P> >::iterator it = q_.begin ();
@@ -327,7 +327,7 @@
template <typename P, typename T>
inline
const std::vector<P>&
- p_priority_queue_fast<P, T>::vect() const
+ p_priority_fast<P, T>::vect() const
{
if (vect_needs_update_)
vect_update_();
@@ -337,7 +337,7 @@
template <typename P, typename T>
inline
const P&
- p_priority_queue_fast<P, T>::operator[](unsigned i) const
+ p_priority_fast<P, T>::operator[](unsigned i) const
{
mln_precondition(i < npoints());
Index: sandbox/pellegrin/set/core/pset_if.hh
--- sandbox/pellegrin/set/core/pset_if.hh (revision 2175)
+++ sandbox/pellegrin/set/core/pset_if.hh (working copy)
@@ -25,10 +25,10 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-#ifndef MLN_CORE_SITE_SET_PSET_IF_HH
-# define MLN_CORE_SITE_SET_PSET_IF_HH
+#ifndef MLN_CORE_SITE_SET_P_IF_HH
+# define MLN_CORE_SITE_SET_P_IF_HH
-/*! \file mln/core/site_set/pset_if.hh
+/*! \file mln/core/site_set/p_if.hh
*
* \brief Definition of the restriction of a point set w.r.t. a predicate.
*/
@@ -42,15 +42,15 @@
{
// Fwd decls.
- template <typename S, typename F> struct pset_if;
- template <typename S, typename F> struct pset_if_fwd_piter_;
- template <typename S, typename F> struct pset_if_bkd_piter_;
+ template <typename S, typename F> struct p_if;
+ template <typename S, typename F> struct p_if_fwd_piter_;
+ template <typename S, typename F> struct p_if_bkd_piter_;
namespace trait
{
template <typename S, typename F>
- struct point_set_< pset_if<S, F> > : public default_point_set_<
pset_if<S, F> >
+ struct point_set_< p_if<S, F> > : public default_point_set_<
p_if<S, F> >
{
typedef trait::point_set::arity::unique arity;
typedef trait::point_set::has_speed::slow has_speed;
@@ -65,7 +65,7 @@
* \return A subset of points.
*/
template <typename S, typename F>
- pset_if<S, F>
+ p_if<S, F>
operator | (const Point_Set<S>& pset, const Function_p2b<F>& f);
@@ -76,26 +76,26 @@
* from point to Boolean.
*/
template <typename S, typename F>
- class pset_if : public internal::point_set_base_< mln_psite(S), pset_if<S,F>
>
+ class p_if : public internal::point_set_base_< mln_psite(S), p_if<S,F> >
{
- typedef pset_if<S,F> self_;
+ typedef p_if<S,F> self_;
typedef internal::point_set_base_<mln_psite(S), self_> super_;
public:
typedef mln_psite(super_) psite;
/// Forward Site_Iterator associated type.
- typedef pset_if_fwd_piter_<S,F> fwd_piter;
+ typedef p_if_fwd_piter_<S,F> fwd_piter;
/// Backward Site_Iterator associated type.
typedef mln::internal::fixme bkd_piter;
/// Constructor with a point set \p pset and a predicate \p f.
- pset_if(const S& pset, const F& f);
+ p_if(const S& pset, const F& f);
/// Constructor without argument.
- pset_if();
+ p_if();
/// Test if \p p belongs to the subset.
@@ -129,20 +129,20 @@
template <typename S, typename F>
inline
- pset_if<S, F>
+ p_if<S, F>
operator | (const Point_Set<S>& pset, const Function_p2b<F>& f)
{
- pset_if<S, F> tmp(exact(pset), exact(f));
+ p_if<S, F> tmp(exact(pset), exact(f));
return tmp;
}
- // pset_if<S,F>
+ // p_if<S,F>
template <typename S, typename F>
inline
bool
- pset_if<S,F>::has(const psite& p) const
+ p_if<S,F>::has(const psite& p) const
{
return pset_.has(p) && f_(p);
}
@@ -150,7 +150,7 @@
template <typename S, typename F>
inline
const box_<mln_point(S)>&
- pset_if<S,F>::bbox() const
+ p_if<S,F>::bbox() const
{
return pset_.bbox();
}
@@ -158,7 +158,7 @@
template <typename S, typename F>
inline
const S&
- pset_if<S,F>::overset() const
+ p_if<S,F>::overset() const
{
return pset_;
}
@@ -166,14 +166,14 @@
template <typename S, typename F>
inline
bool
- pset_if<S,F>::pred(const psite& p) const
+ p_if<S,F>::pred(const psite& p) const
{
return f_(p);
}
template <typename S, typename F>
inline
- pset_if<S,F>::pset_if(const S& pset, const F& f)
+ p_if<S,F>::p_if(const S& pset, const F& f)
: pset_(pset),
f_(f)
{
@@ -181,14 +181,14 @@
template <typename S, typename F>
inline
- pset_if<S,F>::pset_if()
+ p_if<S,F>::p_if()
{
}
template <typename S, typename F>
inline
const F&
- pset_if<S,F>::predicate() const
+ p_if<S,F>::predicate() const
{
return f_;
}
@@ -199,7 +199,7 @@
-# include <mln/core/pset_if_piter.hh>
+# include <mln/core/p_if_piter.hh>
@@ -210,7 +210,7 @@
template <typename S, typename F>
std::size_t
- pset_if<S,F>::npoints() const
+ p_if<S,F>::npoints() const
{
std::size_t n = 0;
fwd_piter p(*this);
@@ -224,4 +224,4 @@
} // end of namespace mln
-#endif // ! MLN_CORE_SITE_SET_PSET_IF_HH
+#endif // ! MLN_CORE_SITE_SET_P_IF_HH
Index: sandbox/pellegrin/set/core/concept/point_set.hh
--- sandbox/pellegrin/set/core/concept/point_set.hh (revision 2175)
+++ sandbox/pellegrin/set/core/concept/point_set.hh (working copy)
@@ -33,7 +33,7 @@
* \brief Definition of the concept of mln::Point_Set.
*
* \todo Think about adding an 'insert' method (not so easy because of
- * pset_if...)
+ * p_if...)
*/
# include <mln/core/concept/point_site.hh>
Index: sandbox/pellegrin/set/core/p_priority_queue.hh
--- sandbox/pellegrin/set/core/p_priority_queue.hh (revision 2175)
+++ sandbox/pellegrin/set/core/p_priority_queue.hh (working copy)
@@ -28,7 +28,7 @@
#ifndef MLN_CORE_SITE_SET_P_PRIORITY_QUEUE_HH
# define MLN_CORE_SITE_SET_P_PRIORITY_QUEUE_HH
-/*! \file mln/core/site_set/p_priority_queue.hh
+/*! \file mln/core/site_set/p_priority.hh
*
* \brief Definition of a point set class based on p_queue with
* priority features.
@@ -51,7 +51,7 @@
{
// Fwd decls.
- template <typename P, typename T> struct p_priority_queue;
+ template <typename P, typename T> struct p_priority;
template <typename P> struct p_array_fwd_piter_;
template <typename P> struct p_array_bkd_piter_;
@@ -59,8 +59,8 @@
{
template <typename P, typename T>
- struct point_set_< p_priority_queue<P, T> >
- : public default_point_set_< p_priority_queue<P, T> >
+ struct point_set_< p_priority<P, T> >
+ : public default_point_set_< p_priority<P, T> >
{
typedef trait::point_set::arity::unique arity;
typedef trait::point_set::has_speed::slow has_speed;
@@ -78,7 +78,7 @@
* a call to npoints() when this container is multiple.
*/
template <typename P, typename T>
- class p_priority_queue : public internal::point_set_base_< P, p_priority_queue<P,
T> >
+ class p_priority : public internal::point_set_base_< P, p_priority<P, T> >
{
public:
@@ -89,7 +89,7 @@
typedef p_array_bkd_piter_<P> bkd_piter;
/// Constructor.
- p_priority_queue();
+ p_priority();
/// Test is \p p belongs to this point set.
bool has(const P& p) const;
@@ -104,10 +104,10 @@
const box_<P>& bbox() const;
/// Push force a point \p p in the queue.
- p_priority_queue<P, T>& push_force(const P& p, T prio = 0);
+ p_priority<P, T>& push_force(const P& p, T prio = 0);
/// Push a point \p p in the queue.
- p_priority_queue<P, T>& push(const P& p, T prio = 0);
+ p_priority<P, T>& push(const P& p, T prio = 0);
/// Pop (remove) the front point \p p from the queue; \p p is the
/// least recently inserted point.
@@ -151,7 +151,7 @@
template <typename P, typename T>
inline
- p_priority_queue<P, T>::p_priority_queue()
+ p_priority<P, T>::p_priority()
{
vect_needs_update_ = false;
bb_needs_update_ = false;
@@ -160,7 +160,7 @@
template <typename P, typename T>
inline
void
- p_priority_queue<P, T>::vect_update_() const
+ p_priority<P, T>::vect_update_() const
{
vect_.clear();
vect_.reserve(npoints());
@@ -176,7 +176,7 @@
template <typename P, typename T>
inline
void
- p_priority_queue<P, T>::bb_update_() const
+ p_priority<P, T>::bb_update_() const
{
bb_.init();
@@ -192,7 +192,7 @@
template <typename P, typename T>
inline
bool
- p_priority_queue<P, T>::has(const P& p) const
+ p_priority<P, T>::has(const P& p) const
{
typename std::map<T, p_queue<P> >::const_iterator it = q_.begin ();
@@ -205,7 +205,7 @@
template <typename P, typename T>
inline
bool
- p_priority_queue<P, T>::is_empty() const
+ p_priority<P, T>::is_empty() const
{
typename std::map<T, p_queue<P> >::const_iterator it = q_.begin ();
@@ -218,7 +218,7 @@
template <typename P, typename T>
inline
size_t
- p_priority_queue<P, T>::npoints() const
+ p_priority<P, T>::npoints() const
{
unsigned res = 0;
@@ -233,7 +233,7 @@
template <typename P, typename T>
inline
const box_<P>&
- p_priority_queue<P, T>::bbox() const
+ p_priority<P, T>::bbox() const
{
mln_precondition(npoints() != 0);
if (bb_needs_update_)
@@ -243,8 +243,8 @@
template <typename P, typename T>
inline
- p_priority_queue<P, T>&
- p_priority_queue<P, T>::push_force(const P& p, T prio)
+ p_priority<P, T>&
+ p_priority<P, T>::push_force(const P& p, T prio)
{
q_[prio].push_force (p);
if (! vect_needs_update_)
@@ -257,8 +257,8 @@
template <typename P, typename T>
inline
- p_priority_queue<P, T>&
- p_priority_queue<P, T>::push(const P& p, T prio)
+ p_priority<P, T>&
+ p_priority<P, T>::push(const P& p, T prio)
{
if (! has(p))
return this->push_force(p, prio);
@@ -269,7 +269,7 @@
template <typename P, typename T>
inline
void
- p_priority_queue<P, T>::pop()
+ p_priority<P, T>::pop()
{
typename std::map<T, p_queue<P> >::reverse_iterator it = q_.rbegin ();
@@ -287,7 +287,7 @@
template <typename P, typename T>
inline
const P&
- p_priority_queue<P, T>::front() const
+ p_priority<P, T>::front() const
{
mln_precondition(! q_.empty());
@@ -302,7 +302,7 @@
template <typename P, typename T>
inline
const P&
- p_priority_queue<P, T>::pop_front()
+ p_priority<P, T>::pop_front()
{
const P& res = this->front();
@@ -313,7 +313,7 @@
template <typename P, typename T>
inline
void
- p_priority_queue<P, T>::clear()
+ p_priority<P, T>::clear()
{
typename std::map<T, p_queue<P> >::iterator it = q_.begin ();
@@ -327,7 +327,7 @@
template <typename P, typename T>
inline
const std::vector<P>&
- p_priority_queue<P, T>::vect() const
+ p_priority<P, T>::vect() const
{
if (vect_needs_update_)
vect_update_();
@@ -337,7 +337,7 @@
template <typename P, typename T>
inline
const P&
- p_priority_queue<P, T>::operator[](unsigned i) const
+ p_priority<P, T>::operator[](unsigned i) const
{
mln_precondition(i < npoints());
Index: sandbox/pellegrin/set/core/p_priority_queue_fast_with_array.hh
--- sandbox/pellegrin/set/core/p_priority_queue_fast_with_array.hh (revision 2175)
+++ sandbox/pellegrin/set/core/p_priority_queue_fast_with_array.hh (working copy)
@@ -28,7 +28,7 @@
#ifndef MLN_CORE_SITE_SET_P_PRIORITY_QUEUE_FAST_WITH_ARRAY_HH
# define MLN_CORE_SITE_SET_P_PRIORITY_QUEUE_FAST_WITH_ARRAY_HH
-/*! \file mln/core/p_priority_queue_fast_with_array.hh
+/*! \file mln/core/p_priority_fast_with_array.hh
*
* \brief Definition of a point set class based on p_queue with
* priority features.
@@ -51,7 +51,7 @@
{
// Fwd decls.
- template <typename P, typename T, unsigned S> struct
p_priority_queue_fast_with_array;
+ template <typename P, typename T, unsigned S> struct p_priority_fast_with_array;
template <typename P> struct p_array_fwd_piter_;
template <typename P> struct p_array_bkd_piter_;
@@ -59,8 +59,8 @@
{
template <typename P, typename T, unsigned S>
- struct point_set_< p_priority_queue_fast_with_array<P, T, S> >
- : public default_point_set_< p_priority_queue_fast_with_array<P, T, S> >
+ struct point_set_< p_priority_fast_with_array<P, T, S> >
+ : public default_point_set_< p_priority_fast_with_array<P, T, S> >
{
typedef trait::point_set::arity::multiple arity;
typedef trait::point_set::has_speed::fast has_speed;
@@ -78,7 +78,7 @@
* a call to npoints() when this container is multiple.
*/
template <typename P, typename T, unsigned S>
- class p_priority_queue_fast_with_array : public internal::point_set_base_< P,
p_priority_queue_fast_with_array<P, T, S> >
+ class p_priority_fast_with_array : public internal::point_set_base_< P,
p_priority_fast_with_array<P, T, S> >
{
public:
@@ -89,7 +89,7 @@
typedef p_array_bkd_piter_<P> bkd_piter;
/// Constructor.
- p_priority_queue_fast_with_array();
+ p_priority_fast_with_array();
/// Test is \p p belongs to this point set.
bool has(const P& p) const;
@@ -104,10 +104,10 @@
const box_<P>& bbox() const;
/// Push force a point \p p in the queue.
- p_priority_queue_fast_with_array<P, T, S>& push_force(const P& p, T
prio = 0);
+ p_priority_fast_with_array<P, T, S>& push_force(const P& p, T prio =
0);
/// Push a point \p p in the queue.
- p_priority_queue_fast_with_array<P, T, S>& push(const P& p, T prio =
0);
+ p_priority_fast_with_array<P, T, S>& push(const P& p, T prio = 0);
/// Pop (remove) the front point \p p from the queue; \p p is the
/// least recently inserted point.
@@ -151,7 +151,7 @@
template <typename P, typename T, unsigned S>
inline
- p_priority_queue_fast_with_array<P, T, S>::p_priority_queue_fast_with_array()
+ p_priority_fast_with_array<P, T, S>::p_priority_fast_with_array()
{
vect_needs_update_ = false;
bb_needs_update_ = false;
@@ -165,7 +165,7 @@
template <typename P, typename T, unsigned S>
inline
void
- p_priority_queue_fast_with_array<P, T, S>::vect_update_() const
+ p_priority_fast_with_array<P, T, S>::vect_update_() const
{
vect_.clear();
vect_.reserve(npoints());
@@ -179,7 +179,7 @@
template <typename P, typename T, unsigned S>
inline
void
- p_priority_queue_fast_with_array<P, T, S>::bb_update_() const
+ p_priority_fast_with_array<P, T, S>::bb_update_() const
{
bb_.init();
@@ -193,7 +193,7 @@
template <typename P, typename T, unsigned S>
inline
bool
- p_priority_queue_fast_with_array<P, T, S>::has(const P& p) const
+ p_priority_fast_with_array<P, T, S>::has(const P& p) const
{
for (unsigned i = 0; i < S; ++i)
if (q_[i].has (p))
@@ -204,7 +204,7 @@
template <typename P, typename T, unsigned S>
inline
bool
- p_priority_queue_fast_with_array<P, T, S>::is_empty() const
+ p_priority_fast_with_array<P, T, S>::is_empty() const
{
for (unsigned i = 0; i < S; ++i)
if (!q_[i].is_empty ())
@@ -215,7 +215,7 @@
template <typename P, typename T, unsigned S>
inline
unsigned
- p_priority_queue_fast_with_array<P, T, S>::npoints() const
+ p_priority_fast_with_array<P, T, S>::npoints() const
{
unsigned res = 0;
@@ -229,7 +229,7 @@
template <typename P, typename T, unsigned S>
inline
const box_<P>&
- p_priority_queue_fast_with_array<P, T, S>::bbox() const
+ p_priority_fast_with_array<P, T, S>::bbox() const
{
mln_precondition(npoints() != 0);
if (bb_needs_update_)
@@ -239,8 +239,8 @@
template <typename P, typename T, unsigned S>
inline
- p_priority_queue_fast_with_array<P, T, S>&
- p_priority_queue_fast_with_array<P, T, S>::push_force(const P& p, T prio)
+ p_priority_fast_with_array<P, T, S>&
+ p_priority_fast_with_array<P, T, S>::push_force(const P& p, T prio)
{
q_[prio].push_force (p);
if (! vect_needs_update_)
@@ -254,8 +254,8 @@
template <typename P, typename T, unsigned S>
inline
- p_priority_queue_fast_with_array<P, T, S>&
- p_priority_queue_fast_with_array<P, T, S>::push(const P& p, T prio)
+ p_priority_fast_with_array<P, T, S>&
+ p_priority_fast_with_array<P, T, S>::push(const P& p, T prio)
{
if (! has(p))
return this->push_force(p, prio);
@@ -266,7 +266,7 @@
template <typename P, typename T, unsigned S>
inline
void
- p_priority_queue_fast_with_array<P, T, S>::pop()
+ p_priority_fast_with_array<P, T, S>::pop()
{
for (unsigned i = S - 1; i != UINT_MAX; --i)
if (!q_[i].is_empty ())
@@ -282,7 +282,7 @@
template <typename P, typename T, unsigned S>
inline
const P&
- p_priority_queue_fast_with_array<P, T, S>::front() const
+ p_priority_fast_with_array<P, T, S>::front() const
{
mln_precondition(! is_empty());
@@ -295,7 +295,7 @@
template <typename P, typename T, unsigned S>
inline
const P&
- p_priority_queue_fast_with_array<P, T, S>::pop_front()
+ p_priority_fast_with_array<P, T, S>::pop_front()
{
const P& res = this->front();
@@ -306,7 +306,7 @@
template <typename P, typename T, unsigned S>
inline
void
- p_priority_queue_fast_with_array<P, T, S>::clear()
+ p_priority_fast_with_array<P, T, S>::clear()
{
for (unsigned i = 0; i < S; ++i)
q_[i].clear ();
@@ -318,7 +318,7 @@
template <typename P, typename T, unsigned S>
inline
const std::vector<P>&
- p_priority_queue_fast_with_array<P, T, S>::vect() const
+ p_priority_fast_with_array<P, T, S>::vect() const
{
if (vect_needs_update_)
vect_update_();
@@ -328,7 +328,7 @@
template <typename P, typename T, unsigned S>
inline
const P&
- p_priority_queue_fast_with_array<P, T, S>::operator[](unsigned n) const
+ p_priority_fast_with_array<P, T, S>::operator[](unsigned n) const
{
mln_precondition(n < npoints());
unsigned i = S - 1;
Index: sandbox/garrigues/level_set.hh
--- sandbox/garrigues/level_set.hh (revision 2175)
+++ sandbox/garrigues/level_set.hh (working copy)
@@ -46,8 +46,8 @@
# include <mln/core/image/inplace.hh>
# include <mln/core/alias/neighb2d.hh>
# include <mln/core/clock_neighb2d.hh>
-# include <mln/core/pset_if_piter.hh>
-# include <mln/core/site_set/pset_if.hh>
+# include <mln/core/p_if_piter.hh>
+# include <mln/core/site_set/p_if.hh>
# include <mln/core/image/sub_image.hh>
# include <mln/core/image/image_if.hh>
# include <mln/core/routine/clone.hh>
Index: sandbox/garrigues/fllt/fllt.hh
--- sandbox/garrigues/fllt/fllt.hh (revision 2175)
+++ sandbox/garrigues/fllt/fllt.hh (working copy)
@@ -39,8 +39,8 @@
# include <mln/core/site_set/p_set.hh>
# include <mln/core/image/inplace.hh>
# include <mln/core/alias/neighb2d.hh>
-# include <mln/core/pset_if_piter.hh>
-# include <mln/core/site_set/pset_if.hh>
+# include <mln/core/p_if_piter.hh>
+# include <mln/core/site_set/p_if.hh>
# include <mln/core/image/sub_image.hh>
# include <mln/core/image/image_if.hh>
# include <mln/core/routine/clone.hh>
Index: tests/core/p_priority_queue.cc
--- tests/core/p_priority_queue.cc (revision 2175)
+++ tests/core/p_priority_queue.cc (working copy)
@@ -25,19 +25,19 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-/*! \file tests/core/p_priority_queue.cc
+/*! \file tests/core/p_priority.cc
*
* \brief Tests on mln::p_priority_queue.
*/
#include <mln/core/alias/point2d.hh>
-#include <mln/core/site_set/p_priority_queue.hh>
+#include <mln/core/site_set/p_priority.hh>
int main ()
{
using namespace mln;
- p_priority_queue<point2d, unsigned> q;
+ p_priority<point2d, unsigned> q;
point2d p1 (6, 9);
point2d p2 (5, 1);
point2d p3 (4, 2);
@@ -25,19 +25,19 @@
*
- * \brief Tests on mln::p_priority_queue.
+ * \brief Tests on mln::p_priority.
*/
#include <mln/core/alias/point2d.hh>
Index: tests/core/p_priority_queue_fast_with_array.cc
--- tests/core/p_priority_queue_fast_with_array.cc (revision 2175)
+++ tests/core/p_priority_queue_fast_with_array.cc (working copy)
@@ -25,19 +25,19 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-/*! \file tests/core/p_priority_queue_fast_with_array.cc
+/*! \file tests/core/p_priority_fast_with_array.cc
*
* \brief Tests on mln::p_priority_queue_fast_with_array.
*/
#include <mln/core/alias/point2d.hh>
-#include <mln/core/p_priority_queue_fast_with_array.hh>
+#include <mln/core/p_priority_fast_with_array.hh>
int main ()
{
using namespace mln;
- p_priority_queue_fast_with_array<point2d, unsigned, 20> q;
+ p_priority_fast_with_array<point2d, unsigned, 20> q;
point2d p1 (6, 9);
point2d p2 (5, 1);
point2d p3 (4, 2);
@@ -25,19 +25,19 @@
*
- * \brief Tests on mln::p_priority_queue_fast_with_array.
+ * \brief Tests on mln::p_priority_fast_with_array.
*/
#include <mln/core/alias/point2d.hh>
Index: tests/core/p_priority_queue_fast.cc
--- tests/core/p_priority_queue_fast.cc (revision 2175)
+++ tests/core/p_priority_queue_fast.cc (working copy)
@@ -25,19 +25,19 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-/*! \file tests/core/p_priority_queue_fast.cc
+/*! \file tests/core/p_priority_fast.cc
*
* \brief Tests on mln::p_priority_queue_fast.
*/
#include <mln/core/alias/point2d.hh>
-#include <mln/core/p_priority_queue_fast.hh>
+#include <mln/core/p_priority_fast.hh>
int main ()
{
using namespace mln;
- mln::p_priority_queue_fast<point2d, unsigned> q;
+ mln::p_priority_fast<point2d, unsigned> q;
point2d p1 (6, 9);
point2d p2 (5, 1);
point2d p3 (4, 2);
@@ -25,19 +25,19 @@
*
- * \brief Tests on mln::p_priority_queue_fast.
+ * \brief Tests on mln::p_priority_fast.
*/
#include <mln/core/alias/point2d.hh>
Index: mln/core/site_set/p_if_piter.hh
--- mln/core/site_set/p_if_piter.hh (revision 2175)
+++ mln/core/site_set/p_if_piter.hh (working copy)
@@ -25,16 +25,16 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-#ifndef MLN_CORE_SITE_SET_PSET_IF_PITER_HH
-# define MLN_CORE_SITE_SET_PSET_IF_PITER_HH
+#ifndef MLN_CORE_SITE_SET_P_IF_PITER_HH
+# define MLN_CORE_SITE_SET_P_IF_PITER_HH
-/*! \file mln/core/pset_if_piter.hh
+/*! \file mln/core/p_if_piter.hh
*
* \brief Definition of iterators on pset_if<S,F>.
*/
# include <mln/core/internal/piter_adaptor.hh>
-# include <mln/core/site_set/pset_if.hh>
+# include <mln/core/site_set/p_if.hh>
namespace mln
@@ -46,19 +46,19 @@
* Parameter \c S is a site set type; parameter F is a function
* from point to Boolean.
*
- * \see mln::pset_if
+ * \see mln::p_if
*/
template <typename Pi, typename S, typename F>
- struct pset_if_piter_
+ struct p_if_piter_
: public internal::piter_adaptor_< Pi, // Adaptee.
- pset_if<S,F>, // Site_Set.
- pset_if_piter_<Pi,S,F> > // Exact.
+ p_if<S,F>, // Site_Set.
+ p_if_piter_<Pi,S,F> > // Exact.
{
/// Constructor without argument.
- pset_if_piter_();
+ p_if_piter_();
/// Constructor from a site set.
- pset_if_piter_(const pset_if<S,F>& s);
+ p_if_piter_(const p_if<S,F>& s);
/// Start an iteration.
void start_();
@@ -67,11 +67,11 @@
void next_();
/// Change the set site targeted by pi_.
- void pi_change_target_(const pset_if<S,F>& s);
+ void pi_change_target_(const p_if<S,F>& s);
private:
- typedef pset_if_piter_<Pi,S,F> self_;
- typedef internal::piter_adaptor_<Pi, pset_if<S,F>, self_> super_;
+ typedef p_if_piter_<Pi,S,F> self_;
+ typedef internal::piter_adaptor_<Pi, p_if<S,F>, self_> super_;
protected:
using super_::s_;
@@ -84,13 +84,13 @@
template <typename Pi, typename S, typename F>
inline
- pset_if_piter_<Pi,S,F>::pset_if_piter_()
+ p_if_piter_<Pi,S,F>::p_if_piter_()
{
}
template <typename Pi, typename S, typename F>
inline
- pset_if_piter_<Pi,S,F>::pset_if_piter_(const pset_if<S,F>& s)
+ p_if_piter_<Pi,S,F>::p_if_piter_(const p_if<S,F>& s)
{
this->change_target(s);
}
@@ -98,7 +98,7 @@
template <typename Pi, typename S, typename F>
inline
void
- pset_if_piter_<Pi,S,F>::start_()
+ p_if_piter_<Pi,S,F>::start_()
{
pi_.start();
while (pi_.is_valid() && ! s_->pred(pi_))
@@ -108,7 +108,7 @@
template <typename Pi, typename S, typename F>
inline
void
- pset_if_piter_<Pi,S,F>::next_()
+ p_if_piter_<Pi,S,F>::next_()
{
do
pi_.next();
@@ -118,7 +118,7 @@
template <typename Pi, typename S, typename F>
inline
void
- pset_if_piter_<Pi,S,F>::pi_change_target_(const pset_if<S,F>& s)
+ p_if_piter_<Pi,S,F>::pi_change_target_(const p_if<S,F>& s)
{
pi_.change_target(s.overset());
}
@@ -128,4 +128,4 @@
} // end of namespace mln
-#endif // ! MLN_CORE_SITE_SET_PSET_IF_PITER_HH
+#endif // ! MLN_CORE_SITE_SET_P_IF_PITER_HH
@@ -25,16 +25,16 @@
*
- * \brief Definition of iterators on pset_if<S,F>.
+ * \brief Definition of iterators on p_if<S,F>.
*/
# include <mln/core/internal/piter_adaptor.hh>
Index: sandbox/pellegrin/set/test/p_priority_queue_fast.cc
--- sandbox/pellegrin/set/test/p_priority_queue_fast.cc (revision 2175)
+++ sandbox/pellegrin/set/test/p_priority_queue_fast.cc (working copy)
@@ -25,19 +25,19 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-/*! \file tests/core/p_priority_queue_fast.cc
+/*! \file tests/core/p_priority_fast.cc
*
* \brief Tests on mln::p_priority_queue_fast.
*/
#include <mln/core/alias/point2d.hh>
-#include <mln/core/p_priority_queue_fast.hh>
+#include <mln/core/p_priority_fast.hh>
int main ()
{
using namespace mln;
- mln::p_priority_queue_fast<point2d, unsigned> q;
+ mln::p_priority_fast<point2d, unsigned> q;
point2d p1 (6, 9);
point2d p2 (5, 1);
point2d p3 (4, 2);
@@ -25,19 +25,19 @@
*
- * \brief Tests on mln::p_priority_queue_fast.
+ * \brief Tests on mln::p_priority_fast.
*/
#include <mln/core/alias/point2d.hh>
Index: sandbox/pellegrin/set/test/p_priority_queue.cc
--- sandbox/pellegrin/set/test/p_priority_queue.cc (revision 2175)
+++ sandbox/pellegrin/set/test/p_priority_queue.cc (working copy)
@@ -25,19 +25,19 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-/*! \file tests/core/p_priority_queue.cc
+/*! \file tests/core/p_priority.cc
*
* \brief Tests on mln::p_priority_queue.
*/
#include <mln/core/alias/point2d.hh>
-#include <mln/core/site_set/p_priority_queue.hh>
+#include <mln/core/site_set/p_priority.hh>
int main ()
{
using namespace mln;
- p_priority_queue<point2d, unsigned> q;
+ p_priority<point2d, unsigned> q;
point2d p1 (6, 9);
point2d p2 (5, 1);
point2d p3 (4, 2);
@@ -25,19 +25,19 @@
*
- * \brief Tests on mln::p_priority_queue.
+ * \brief Tests on mln::p_priority.
*/
#include <mln/core/alias/point2d.hh>
Index: sandbox/pellegrin/set/test/p_priority_queue_fast_with_array.cc
--- sandbox/pellegrin/set/test/p_priority_queue_fast_with_array.cc (revision 2175)
+++ sandbox/pellegrin/set/test/p_priority_queue_fast_with_array.cc (working copy)
@@ -25,19 +25,19 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-/*! \file tests/core/p_priority_queue_fast_with_array.cc
+/*! \file tests/core/p_priority_fast_with_array.cc
*
* \brief Tests on mln::p_priority_queue_fast_with_array.
*/
#include <mln/core/alias/point2d.hh>
-#include <mln/core/p_priority_queue_fast_with_array.hh>
+#include <mln/core/p_priority_fast_with_array.hh>
int main ()
{
using namespace mln;
- p_priority_queue_fast_with_array<point2d, unsigned, 20> q;
+ p_priority_fast_with_array<point2d, unsigned, 20> q;
point2d p1 (6, 9);
point2d p2 (5, 1);
point2d p3 (4, 2);
@@ -25,19 +25,19 @@
*
- * \brief Tests on mln::p_priority_queue_fast_with_array.
+ * \brief Tests on mln::p_priority_fast_with_array.
*/
#include <mln/core/alias/point2d.hh>